from setuptools import setup

setup(
    name='solidAPI',
    version='0.1.8.6',
    packages=['solidAPI'],
    url='https://github.com/DoellBarr',
    license='MIT',
    author='Shohih Abdul',
    author_email='shohih242@gmail.com',
    description='A Library for solidAPI',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
